@@ -4,17 +4,22 @@ name = "doctable"
 from sqlalchemy.sql import and_, or_, not_
 
 from .doctable import DocTable
-from .doctablelegacy import DocTableLegacy
 from .bootstrap import DocBootstrap
 from .distribute import Distribute
+from .schemas import parse_schema, column_type_map
+from .connectengine import ConnectEngine
+
 
 from .migration import migrate_db
 
 from .util import list_tables
 
 # for parsing
-from .pipeline import ParsePipeline, component
-from .parsetree import ParseTree, ParseNode
+from .pipeline import ParsePipeline, Comp, components
+from .parsetree import ParseTree, Token
+from .parse import * # perhaps debatable
 
-from .docparser import DocParser # legacy
+# all legacy
+from .docparser import DocParser
+from .doctablelegacy import DocTableLegacy
 
