@@ -166,14 +166,46 @@ class DocTable:
                                              new_table=self._new_table)
         
         # connect to database
-        self._conn = self._engine.get_connection()
+        self._conn = self._engine.connect()
         
     def __del__(self):
         ''' Closes database connection to prevent locking db.
         '''
+        # apparently engines and connections are garbage collected using event handlers?
+        # I don't understand this, but solved some big issues by just doing nothing.
+        
         #self._engine.remove_table(self._table) # remove from engine metadata
-        self.close_conn()
+        #self.close_conn()
+        pass
+
+        
     
+    #################### Connection Methods ###################
+    
+    def close_conn(self):
+        ''' Closes connection to db (if one exists). '''
+        if self._conn is not None:
+            self._conn.close()
+            self._conn = None
+            
+        
+    def open_conn(self):
+        ''' Opens connection to db (if one does not exist). '''
+        
+        if self._conn is None:
+            self._conn = self._engine.connect()
+    
+    def reopen_engine(self, open_conn=None):
+        ''' Opens connection engine. 
+        Args:
+            open_conn (bool): create a new db connection.
+        '''
+        self.close_conn()
+        self._engine.reopen()
+        if open_conn or (open_conn is None and self.persistent_conn):
+            self.open_conn()
+
+
     #################### Convenience Methods ###################
     
     def __str__(self) -> str:
@@ -247,29 +279,7 @@ class DocTable:
         return self._engine.schema_df(self._tabname)
     
             
-    #################### Connection Methods ###################
-    
-    def close_conn(self):
-        ''' Closes connection to db (if one exists). '''
-        if self._conn is not None:
-            self._conn.close()
-            self._conn = None
-        
-    def open_conn(self):
-        ''' Opens connection to db (if one does not exist). '''
-        
-        if self._conn is None:
-            self._conn = self._engine.get_connection()
-    
-    def reopen_engine(self, open_conn=None):
-        ''' Opens connection engine. 
-        Args:
-            open_conn (bool): create a new db connection.
-        '''
-        self.close_conn()
-        self._engine.reopen()
-        if open_conn or (open_conn is None and self.persistent_conn):
-            self.open_conn()
+
     
     ################# INSERT METHODS ##################
     
@@ -440,7 +450,7 @@ class DocTable:
         if where is not None:
             q = q.where(where)
         if wherestr is not None:
-            q = q.where(sqlalchemy.text(wherestr))
+            q = q.where(sqlalchemy.text(f'({wherestr})'))
         if orderby is not None:
             if is_sequence(orderby):
                 q = q.order_by(*orderby)
@@ -613,8 +623,8 @@ class DocTable:
         elif self._conn is not None:
             r = self._conn.execute(query)
         else:
-            with self._engine.get_connection() as conn:
-                r = conn.execute(query)
+            # execute query using connectengine directly
+            r = self._engine.execute(query)
         return r
     
     
